==> everrest-core-1.0.4-sources.jar: org/everrest/core/DependencyNameDetector.java <==
/*
 * Copyright (C) 2011 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.everrest.core;

/**
 * Implementation of this interface determine name of dependency required for constructors or fields of Resource or
 * Provider. Typically the name of the dependency may be set by annotation with value as component's qualifier, e.g.
 * &#064javax.inject.Named.
 *
 * @author <a href="mailto:andrew00x@gmail.com">Andrey Parfonov</a>
 * @version $Id: $
 */
public interface DependencyNameDetector
{
   /**
    * Get name of parameter.
    *
    * @param parameter the Parameter
    * @return name of <code>parameter</code> or <code>null</code> if name can't be detected by particular
    *         DependencyNameDetector
    */
   String getName(Parameter parameter);
}

==> everrest-core-1.1.1-sources.jar: org/everrest/core/DependencyNameDetector.java <==
/*
 * Copyright (C) 2011 eXo Platform SAS.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.everrest.core;

/**
 * Implementation of this interface determine name of dependency required for constructors or fields of Resource or
 * Provider. Typically the name of the dependency may be set by annotation with value as component's qualifier, e.g.
 * &#064javax.inject.Named.
 *
 * @author <a href="mailto:andrew00x@gmail.com">Andrey Parfonov</a>
 * @version $Id: $
 */
public interface DependencyNameDetector {
    /**
     * Get name of parameter.
     *
     * @param parameter
     *         the Parameter
     * @return name of <code>parameter</code> or <code>null</code> if name can't be detected by particular
     *         DependencyNameDetector
     */
    String getName(Parameter parameter);
}
